Crate cosmian_kms_interfaces

Crate cosmian_kms_interfaces 

Macros

as_hsm_uid

Structs

EncryptedContent
HsmObject
HSM object representation
HsmStore
A single adapter that wraps an Arc<dyn HSM> and implements both ObjectsStore and CryptoOracle. Callers can Clone the backend cheaply (only the inner Arc is cloned) to register it in both the object-store and crypto-oracle maps.
KeyMetadata
ObjectWithMetadata
An object with its metadata such as owner, permissions and state
RsaPrivateKeyMaterial
RSA private key value representation All values are in big-endian format
RsaPublicKeyMaterial
RSA public key value representation All values are in big-endian format

Enums

AtomicOperation
An atomic operation on the objects database
CryptoAlgorithm
HsmKeyAlgorithm
Supported key algorithms
HsmKeypairAlgorithm
Supported key pair algorithms
HsmObjectFilter
Supported object filters on find
InterfaceError
KeyMaterial
Key material representation
KeyType
Supported cryptographic object types in plugins
SigningAlgorithm
Signing algorithms supported by the crypto oracle / HSM.

Constants

SECS_PER_DAY
Number of seconds in one day — the finest granularity PKCS#11 CK_DATE can represent.

Traits

CryptoOracle
HSM
HSM trait This trait defines the operations that can be performed on an HSM. The HSM is assumed to be a PKCS#11 compliant device.
ObjectsStore
Trait that must implement all object stores (DBs, HSMs, etc.) that store objects
PermissionsStore
Trait that the stores must implement to store permissions

Type Aliases

InterfaceResult