Macros
Structs
- Encrypted
Content - HsmObject
- HSM object representation
- HsmStore
- A single adapter that wraps an
Arc<dyn HSM>and implements bothObjectsStoreandCryptoOracle. Callers canClonethe backend cheaply (only the innerArcis cloned) to register it in both the object-store and crypto-oracle maps. - KeyMetadata
- Object
With Metadata - An object with its metadata such as owner, permissions and state
- RsaPrivate
KeyMaterial - RSA private key value representation All values are in big-endian format
- RsaPublic
KeyMaterial - RSA public key value representation All values are in big-endian format
Enums
- Atomic
Operation - An atomic operation on the objects database
- Crypto
Algorithm - HsmKey
Algorithm - Supported key algorithms
- HsmKeypair
Algorithm - Supported key pair algorithms
- HsmObject
Filter - Supported object filters on find
- Interface
Error - KeyMaterial
- Key material representation
- KeyType
- Supported cryptographic object types in plugins
- Signing
Algorithm - Signing algorithms supported by the crypto oracle / HSM.
Constants
- SECS_
PER_ DAY - Number of seconds in one day — the finest granularity PKCS#11
CK_DATEcan represent.
Traits
- Crypto
Oracle - HSM
- HSM trait This trait defines the operations that can be performed on an HSM. The HSM is assumed to be a PKCS#11 compliant device.
- Objects
Store - Trait that must implement all object stores (DBs, HSMs, etc.) that store objects
- Permissions
Store - Trait that the stores must implement to store permissions